@@ -1,4 +1,4 @@
-function _classPrivateFieldBase(receiver, privateKey) {
+function _classPrivateFieldLooseBase(receiver, privateKey) {
   if (!Object.prototype.hasOwnProperty.call(receiver, privateKey)) {
     throw new TypeError("attempted to use private field on non-instance");
   }
